# plyder

[![PyPI](https://img.shields.io/pypi/v/plyder.svg?style=flat)](https://pypi.python.org/pypi/plyder)
[![Tests](https://github.com/kpj/plyder/workflows/Tests/badge.svg)](https://github.com/kpj/plyder/actions)

Download manager with web-interface.


## Installation

```python
$ pip install plyder
```


## Usage

```bash
$ plyder
```

`plyder` works out of the box. Though you might want to adapt the configuration to your taste.
